==> udm-plugin-api-3.5.0-sources.jar: com/xebialabs/deployit/plugin/api/udm/base/BaseDeployableFolderArtifact.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.api.udm.base;

import java.util.ArrayList;
import java.util.List;

import com.xebialabs.deployit.plugin.api.udm.Metadata;
import com.xebialabs.deployit.plugin.api.udm.artifact.FolderArtifact;
import com.xebialabs.overthere.OverthereFile;

/**
 * Represents a directory of files.
 */
@SuppressWarnings("serial")
@Metadata
public abstract class BaseDeployableFolderArtifact extends BaseDeployableArtifact implements FolderArtifact {

	public List<OverthereFile> getFiles() {
		List<OverthereFile> files = new ArrayList<OverthereFile>();
		OverthereFile folderLocation = getFile();
		if (folderLocation.exists() && folderLocation.isDirectory() && folderLocation.canRead()) {
			List<? extends OverthereFile> allFiles = folderLocation.listFiles();
			if (allFiles != null) {
				files.addAll(allFiles);
			}
		}
		return files;
	}

}

==> udm-plugin-api-3.7.5-sources.jar: com/xebialabs/deployit/plugin/api/udm/base/BaseDeployableFolderArtifact.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.api.udm.base;

import java.util.ArrayList;
import java.util.List;

import com.xebialabs.deployit.plugin.api.udm.Metadata;
import com.xebialabs.deployit.plugin.api.udm.artifact.FolderArtifact;
import com.xebialabs.overthere.OverthereFile;

@SuppressWarnings("serial")
@Metadata(virtual = true, description = "A folder artifact that can be deployed")
public class BaseDeployableFolderArtifact extends BaseDeployableArtifact implements FolderArtifact {

	public List<OverthereFile> getFiles() {
		List<OverthereFile> files = new ArrayList<OverthereFile>();
		OverthereFile folderLocation = getFile();
		if (folderLocation.exists() && folderLocation.isDirectory() && folderLocation.canRead()) {
			List<? extends OverthereFile> allFiles = folderLocation.listFiles();
			if (allFiles != null) {
				files.addAll(allFiles);
			}
		}
		return files;
	}

}
